{% extends ac_app_name|add:'/auth/base.html' %}
{% block content %}
<h3 class="fw-normal mb-3">{{_('reset_password')}}</h3>
<form method="post" style="width: 23rem;">
    {% csrf_token %}

    <!-- Password1 -->
    <div data-mdb-input-init class="form-outline mb-4">
        <input type="password" id="id_new_password1" name="new_password1" autocomplete="new_password1"
               class="form-control"/>
        <label class="form-label" for="id_new_password1">{{ form.new_password1.label }}</label>
    </div>
    <div class="text-danger">
        {% if form.new_password1.errors %} {{form.new_password1.errors}} {% endif %}
    </div>
    {% if form.new_password1.errors %} {{form.new_password1.help_text}} {% endif %}


    <!-- Password2 -->
    <div data-mdb-input-init class="form-outline mb-4">
        <input type="password" id="id_new_password2" name="new_password2" autocomplete="new_password2"
               class="form-control"/>
        <label class="form-label" for="id_new_password2">{{ form.new_password2.label }}</label>
    </div>
    <div class="text-danger">
        {% if form.new_password2.errors %} {{form.new_password2.errors}} {% endif %}
    </div>
    {% if form.new_password2.errors %} {{form.new_password2.help_text}} {% endif %}

    <div class="pt-1 mb-4">
        <button class="btn btn-info btn-block" type="submit">{{_('reset_password')}}</button>
    </div>
</form>
{% endblock %}