<div class="loader-div position-fixed w-100 h-100 opacity-75 bg-light bg-gradient"
     style="z-index: 30001; display:none;">
    <p class="d-flex align-items-center justify-content-center h-100">
        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
             style="margin: auto; display: block;" width="100px" height="100px"
             viewBox="0 0 100 100" preserveAspectRatio="xMidYMid">
            <g transform="translate(20 20)">
                <rect x="-15" y="-15" width="30" height="30" fill="#93dbe9">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.4s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(50 20)">
                <rect x="-15" y="-15" width="30" height="30" fill="#689cc5">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.3s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(80 20)">
                <rect x="-15" y="-15" width="30" height="30" fill="#5e6fa3">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.2s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(20 50)">
                <rect x="-15" y="-15" width="30" height="30" fill="#689cc5">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.3s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(50 50)">
                <rect x="-15" y="-15" width="30" height="30" fill="#5e6fa3">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.2s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(80 50)">
                <rect x="-15" y="-15" width="30" height="30" fill="#3b4368">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.1s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(20 80)">
                <rect x="-15" y="-15" width="30" height="30" fill="#5e6fa3">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.2s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(50 80)">
                <rect x="-15" y="-15" width="30" height="30" fill="#3b4368">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="-0.1s"></animateTransform>
                </rect>
            </g>
            <g transform="translate(80 80)">
                <rect x="-15" y="-15" width="30" height="30" fill="#191d3a">
                    <animateTransform attributeName="transform" type="scale" repeatCount="indefinite" calcMode="spline"
                                      dur="1s" values="1;1;0.2;1;1" keyTimes="0;0.2;0.5;0.8;1"
                                      keySplines="0.5 0.5 0.5 0.5;0 0.1 0.9 1;0.1 0 1 0.9;0.5 0.5 0.5 0.5"
                                      begin="0s"></animateTransform>
                </rect>
            </g>
        </svg>
    </p>
</div>