{% extends ac_app_name|add:'/auth/base.html' %}
{% block content %}
<h3 class="fw-normal mb-3">{{_('reset_password')}}</h3>
<form method="post" style="width: 23rem;">
    {% csrf_token %}

    <!-- Email -->
    <div data-mdb-input-init class="form-outline">
        <input type="email" id="id_email" name="email" value="{{form.email.value|default_if_none:''}}"
               class="form-control"/>
        <label class="form-label" for="id_email">{{ form.email.label }}</label>
    </div>
    <div class="text-danger mt-2">
        {% if form.email.errors %} {{form.email.errors}} {% endif %}
    </div>
    {% if form.email.errors %} {{form.email.help_text}} {% endif %}

    <div class="pt-1 mb-4">
        <button class="btn btn-info btn-block" type="submit">{{_('request_password_reset')}}</button>
    </div>

</form>
{% endblock %}